import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk/standard/taboola_standard_builder.dart';

import 'package:taboola_sdk_example/DefaultProperties.dart' as PublisherProperties;

class TOnlineScreen extends StatefulWidget {
  TOnlineScreen(this.articleId);
  final String articleId;

  static const String routeName = "/webview";

  @override
  _WebViewArticleState createState() => new _WebViewArticleState("myArticleId");
}

class _WebViewArticleState extends State<TOnlineScreen> {
  _WebViewArticleState(this.articleId);

  String articleId;
  double webViewHeight;
  bool embedFlag = false;

  InAppWebViewController webView;

  void taboolaDidShow(String placement) {
    log("Taboola did show");
  }

  void taboolaDidResize(String placement, double height) {
    log("Taboola did resize, height: $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    log("Taboola did fail to load, error: $error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    return true;
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  Widget _buildBody(BuildContext context) {
    Taboola.init(PublisherInfo(PublisherProperties.publisher));
    TaboolaStandardBuilder taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(PublisherProperties.pageUrl, PublisherProperties.pageType);

    TaboolaStandardListener taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    TaboolaStandard taboolaStandard = taboolaStandardBuilder.build(PublisherProperties.placement, PublisherProperties.mode, true, taboolaStandardListener);

    return SingleChildScrollView(
        child: Column(
            children: [
              Container(child: Align(alignment: Alignment.centerLeft,child: Text(
                "kicker",
                style: TextStyle(
                    fontWeight: FontWeight.bold,
                    color: Colors.black45,
                    fontSize: 16),
              ),),
                margin: EdgeInsets.all(10.0),),
              Container(child: Align(alignment: Alignment.centerLeft, child: Text(
                "headline",
                style: TextStyle(
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                    fontSize: 22),
              ),),
                  margin: EdgeInsets.only(left: 10.0, right: 10.0, bottom: 10.0)),
              Container(child: Align(alignment: Alignment.centerLeft, child: Text(
                "published",
                style: TextStyle(
                    color: Colors.black26,
                    fontSize: 14),
              ),),
                  margin: EdgeInsets.only(left: 10.0, right: 10.0, bottom: 10.0)),
              Container(child: Align(alignment: Alignment.centerLeft, child: Text(
                "leadImage.caption",
                style: TextStyle(
                    color: Colors.black45,
                    fontSize: 14),
              ),),
                margin: EdgeInsets.all(10.0),
              ),
              Container(child: Align(alignment: Alignment.centerLeft, child: Text(
                "Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, Texty text, ",
                style: TextStyle(
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                    fontSize: 18),
              ),),
                margin: EdgeInsets.only(left: 10.0, right: 10.0, bottom: 10.0),
              ),
              Container(
                  height: webViewHeight ?? 1000,
                  child:
                  InAppWebView(
                    initialOptions: InAppWebViewGroupOptions(
                        crossPlatform: InAppWebViewOptions(
                          debuggingEnabled: true,
                        )
                    ),
                    onWebViewCreated: (InAppWebViewController controller) async {
                      String urlToArticle = "https://www.google.com";
                      webView = controller;
                      webView.loadUrl(url: urlToArticle);
                    },
                    onLoadStop: (InAppWebViewController controller, String url) {
                      webView.injectJavascriptFileFromAsset(
                          assetFilePath: "assets/webViewTest/app-chrome-74.js");
                      webView.injectCSSFileFromAsset(
                          assetFilePath: "assets/webViewTest/article_content.css");
                      webView.evaluateJavascript(
                          source: "document.body.scrollHeight")
                          .then((height) {
                        Future.delayed(Duration(milliseconds: 100), () {
                          log(height.toString());
                          this.webViewHeight =
                              double.tryParse(height.toString());
                          //taboolaStandard = taboolaStandardBuilder.build(taboolaPlacement, taboolaMode, true, taboolaStandardListener);
                          setState(() {});
                          Future.delayed(Duration(milliseconds: 1000), () {
                            embedFlag = true;
                          });
                        });
                      });
                    },
                  )
              ),
              Container(
                margin: EdgeInsets.all(10.0),
                child: taboolaStandard,
              )
            ])
    );
  }


  void openWebView(BuildContext context, String articleId) {
    Navigator.push(
      context,
      MaterialPageRoute(builder: (context) => TOnlineScreen(articleId)),
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              backgroundColor: Colors.white,
              leading:
              IconButton(
                icon: Icon(Icons.arrow_back, color: Colors.black,),
                onPressed: () => Navigator.of(context).pop(),
              ),
              title: Text("t-online.", style: TextStyle(color: Colors.black),),
            ),
            body: _buildBody(context)
        )
    );
  }
}