import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart' as PublisherProperties;

class SingleChildScrollViewTest extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Taboola.init(PublisherInfo(PublisherProperties.publisher));
    TaboolaStandardBuilder taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(PublisherProperties.pageUrl, PublisherProperties.pageType);

    TaboolaStandardListener taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    TaboolaStandard taboolaStandard = taboolaStandardBuilder.build(PublisherProperties.placement_widget, PublisherProperties.mode, true, taboolaStandardListener);

    /// At the moment, SingleChildScrollView fits more our Widgets. In general, and any Feed integration, we recommend using CustomScrollView for NestedScrolling solution.
    return SingleChildScrollView(
        controller: taboolaStandard.scrollController, //Using SingleChildScrollView requires using 'controller: taboolaStandard.scrollController', otherwise the y value of Taboola's Unit rect does not get updated properly by Flutter.
        child: Column(children: [
          _getContentColumn(),
          taboolaStandard,
    ]));
  }

  Widget _buildSeparator() {
    return Container(
      height: 8,
      width: 512,
      color: Color.fromARGB(255, 50, 50, 50),
    );
  }

  Widget _getContentColumn() {
    return Center(
     child: Column(
         mainAxisAlignment: MainAxisAlignment.start,
         mainAxisSize: MainAxisSize.max,
         crossAxisAlignment: CrossAxisAlignment.stretch,
         children: [
           Text(
             'This Example does not scroll inside the WebView content and fits "Taboola Widget" scenarios. For "Taboola Feed" integrations, we recommend using CustomScrollView for NestedScrolling solution',
           ),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
         ]),
    );
  }

  Widget _buildTaboolaFlutterLogo() {
    return Container(
      color: Color.fromARGB(255, 230, 241, 255),
      height: 300,
      padding: EdgeInsets.all(32.0),
      child: Image(
        image: AssetImage('images/flutter_taboola_logo.png'),
        alignment: Alignment.center,
      ),
    );
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did cilck on item:$itemId with clickUrl:$clickUrl in placement:$placement of organic:$organic");
    return false;
  }
}


// Just a Test WebView
class TestWebView extends StatelessWidget {
  WebView _webView = new WebView(
    initialUrl: "https://www.ynet.co.il",
    javascriptMode: JavascriptMode.unrestricted,

  );

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 560,
      width: 400,
      child: _webView,
    );
  }

}
